@@ -270,7 +270,7 @@ rmd_RCM_index_output <- function(sur, s_name) {
            paste0("lines(Year, RCMdata@Index[, ", sur, "], col = \"black\", typ = \"o\")"),
            "if (!is.null(scenario$names)) legend(\"topleft\", scenario$names, col = scenario$col_legend, lty = scenario$lty, lwd = scenario$lwd)",
            paste0("log_like <- sapply(report_list, function(x) sum(x$nll_index[, ", sur, ", 1]))"),
-           "if (!sum(log_like)) title(\"**Index not in likelihood**\", col.main = \"magenta\")",
+           "if (!sum(log_like, na.rm=TRUE)) title(\"**Index not in likelihood**\", col.main = \"magenta\")",
            "```\n",
            "",
            paste0("```{r, fig.cap = \"Observed (black) and predicted (red) index values for ", s_name[sur], ". Error bars indicate 95% confidence intervals for observed values.\"}"),
@@ -283,7 +283,7 @@ rmd_RCM_index_output <- function(sur, s_name) {
            "  arrows(Year[ind], y0 = err[ind, 1], y1 = err[ind, 2], length = 0, lwd = 1.5)",
            "  if (!is.null(scenario$names)) legend(\"topleft\", scenario$names, col = scenario$col_legend, lty = scenario$lty, lwd = scenario$lwd)",
            paste0("  log_like <- sapply(report_list, function(x) sum(x$nll_index[, ", sur, ", 1]))"),
-           "  if (!sum(log_like)) title(\"**Index not in likelihood**\", col.main = \"magenta\")",
+           "  if (!sum(log_like, na.rm=TRUE)) title(\"**Index not in likelihood**\", col.main = \"magenta\")",
            "}",
            "```\n",
            "",
