@@ -96,8 +96,9 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
   data <- list(model = "SCA", C_hist = C_hist, rescale = rescale, 
                I_hist = I_hist, I_sd = matrix(0.01, n_y, 1), I_units = 1, I_vul = matrix(1, n_age, 1), 
                abs_I = 0, nsurvey = 1, LWT = 1,
-               CAA_hist = matrix(0, n_y, max_age), CAA_n = rep(0, n_y), 
+               CAA_hist = matrix(0, n_y, n_age), CAA_n = rep(0, n_y), 
                CAL_hist = matrix(0, n_y, 1), CAL_n = rep(0, n_y),
+               IAA_hist = array(0, c(n_y, n_age, 1)), IAA_n = matrix(0, n_y, 1),
                n_y = n_y, n_age = n_age, n_bin = 1L, M_data = 1,
                weight = Wa, PLA = matrix(1, n_age, 1), mat = mat_age, vul_type = "logistic",
                SR_type = SR, comp_dist = "multinomial", catch_eq = catch_eq,
